/***************************************************************
*																					*
*	app.h: Application Initialization Header							*
*																					*
*	Copyright 2006 by Pion and Simon Electronics.  All				*
*	rights reserved.															*
*																					*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************/

	// define undef

#define	FIRMWARE_VERSION	"3.3.1"

	// Debug Switches

#undef	DEBUG			// define to get debug functionality

#ifdef	DEBUG

#undef	AU_DEBUG					// Audio Control Module debugging
#undef	EXEC_DEBUG				// Executive Module debugging
#undef	IO_DEBUG					// Simulates bit I/O.
#undef	PL_DEBUG					// Enable PL tone debug helps
#undef	RX_DEBUG					// Enable Rx debug helps
#undef	TX_DEBUG					// Enable Tx debug helps
#undef	MORSE_DEBUG				// Enable Morse debug helps
#undef	DTMF_DEBUG				// Enable DTMF debug helps
#undef	PARSE_DEBUG				// Debug parser.
#undef	DEBUG_SHORT_TIMEOUTS	// Shorten CWID and Tx timeouts.
#define	CDEBUG					// cdebug.c functions
#undef	FG_INTERP_TEST			// Func Gen Interpolation testing

#endif	// DEBUG


//		*** GENERAL DEFINITIONS ****

#define SIGNON1	"PSE-508-3 PCB 2.1"

#define SIGNON2	" Repeater Controller\n\r" \
						"Firmware Version " FIRMWARE_VERSION \
						" " __DATE__ "\r\n\n"

#define SYSCLK		20000		// System clock freq in KHz

#define 	Z_WORDSTRING	20		// Length of word string

	//	Timer 0 Definitions

	//	Write the start and stop commands below to TCCR0:

#define TMR0_PRESCALER	256

#define TMR0_START		0x04	// Starts timer 1/256 prescaler
#define TMR0_STOP			0x00	// Stops timer.

	// Define TMR0_COUNT to give us interrupts every 1 ms.:

#define TMR0_COUNT		(char)(-((SYSCLK/TMR0_PRESCALER)+0.5))


//		*** State Machine ID Numbers ***

#define SM_RX				0		// Receiver State Machine
#define SM_TX				1		// Transmitter State Machine
#define SM_MORSE			2		// Audio Output State Machine
#define SM_PL				3		// PL Tone State Machine
#define SM_DTMF			4		// DTMF State Machine
#define SM_SIO				5		// Serial I/O State Machine
#define SM_AUDIO			6		// Audio control module
#define SM_WDOG			7		// Watchdog Timer

#define NUM_TASKS			8		// Total number of state machines


//		*** Timer ID Numbers ***

#define TM_DTMF_CHECK			0	// Poll for DTMF character
#define TM_RX_SQUELCH_POLL		1	// Poll squelch status
#define TM_MORSE_DIT				2	// Morse waveform duration
#define TM_MORSE_DLY				3	// Morse inter-bit delay
#define TM_PL_TIMEOUT			4	// PL tone drop timeout.
#define TM_RX_VID_TIMEOUT		5	// VID recording timeout.
#define TM_AUDIO_TMR1			6	// Audio Module GP Timer 1
#define TM_TX_TIMEOUT			7	// Transmitter timeout
#define TM_TX_ID					8	// ID timeout.
#define TM_TX_HANG				9	// Duration of hang time.
#define TM_DTMF_PASS_TIMEOUT	10	// DTMF password timeout.
#define TM_AUDIO_REVBURST		11	// Audio Module Reverse Burst
#define TM_WDOG					12	// Watchdog refresh timer
#define TM_ANNOUNCE_POLL		13	// Announcement Mode
#define TM_REVERSE_BURST		14	// Reverse burst PTT delay.
#define TM_PL_SQUELCH			15	// Turn off PL after squelch.


#define NUM_TIMERS		16		// Total number of timers


//		*** Event and Message ID Numbers ***

	// Note: Event and Message ID Numbers must not use
	// the number 0.  It is reserved for system use.

#define NUM_MSGS			4		// Max number of messages in FIFO.
										// Must be less than or equal to 255.

#define NUM_EVENTS		8		// Max number of events in FIFO.
										// Must be less than or equal to 255.

	// Events associated with the Rx State Machine

#define EV_SQUELCHED		1		// 01 A channel's squelch closed.
#define EV_UNSQUELCHED	2		// 02 A channel's squelch opened.
#define EV_VID_TO			3		// 03 Voice ID Recording Timed Out.
#define MSG_VID_ENA		4		// 04 Enable Voice ID Recording.
#define EV_RX_TXTO		5		// 05 SM_TX had a transmitter timeout

	// Events associated with the Morse State Machine

#define EV_MORSE_DIT_TO	10		// 0A Morse dit timer timed out
#define EV_MORSE_DLY_TO	11		// 0B Morse delay timer timed out
#define MSG_MORSE_SRAM 	12		// 0C Start SRAM string output
#define EV_MORSE_CMPLT 	13		// 0D Morse output is complete
#define MSG_MORSE_FLASH	14		// 0E Start FLASH string output
#define EV_MORSE_HANG	15		// 0F Do hang timer
#define MSG_MORSE_WISPER 16	// 10 Reduce tone volume.
#define MSG_MORSE_SHOUT	17		// 11 Normal tone volume

	// Events associated with the PL Detector State Machine

#define EV_PL_LOCKED			30		// 1E PL Detector locked.
#define EV_PL_UNLOCKED		31		// 1F PL Detector unlocked.
#define EV_PL_SAMPLE			32		// 20 New PL sample detected.
//#define EV_PL_MISSING		33		// 21 Expected PL edge missing.
#define EV_PL_TIMEOUT		34		// 22 PL Timer timed out
#define MSG_PL_UNSQUELCHED	35		// 23 Turn PL Detector on
#define MSG_PL_SQUELCHED	36		// 24 Turn PL Detector off
#define EV_PL_SQUELCH_TO	37		// 25 Squelch timer timeout.

	// Events associated with the DTMF State Machine

#define MSG_DTMF_ENA		40		// 28 Enable DTMF code detection
#define MSG_DTMF_DIS		41		// 29 Disable DTMF code detection
#define EV_DTMF_NEW		42		// 2A New DTMF code detected
#define MSG_DTMF_INPROG	43		// 2B DTMF detection in progress
#define EV_DTMF_OK		44		// 2C DTMF complete and status is OK
#define EV_DTMF_ERR		45		// 2D DTMF complete, with error.
#define EV_DTMF_PASS_TO	46		// 2E DTMF password timeout.

	// Events associated with the Tx State Machine

#define MSG_TX_REPEAT	50		// 32 Enable repeating
#define MSG_TX_ENDRPT	51		// 33 Disable repeating
#define EV_TX_IDTIME		52		// 34 Time to do CW ID
#define EV_TX_TIMEOUT	53		// 35 Transmitter timeout
#define EV_TX_HANG		54		// 36 Hang timer timed out.
#define MSG_TX_IDCMD		55		// 37 Do an ID on command.
#define MSG_TX_OFF		56		// 38 Do an ID and turn off.
#define MSG_TX_ON			57		// 39 Turn on and do an ID.
#define EV_TX_ANNTO		58		// 3A Announcement timeout
#define EV_TX_REVBURST	59		// 3B Announcement timeout


	// Events associated with the RS-232 Interface

#define EV_SIO_RXRDY		70		// 46 Receive data ready at UART

	// Events associated with the Audio Control Module

#define MSG_AUD_START		80		// 50 Start doing audio ouptut tasks.
#define EV_AUD_CMPLT			81		// 51 All audio tasks have been completed.
#define EV_AUD_TMR1			82		// 52 Audio GP Timer 1 Expired
#define EV_AUD_TMR2			83		// 53 Audio GP Timer 2 Expired
//#define MSG_AUD_CANCEL_CB	84		// 54 Cancel Courtesy Beep
#define MSG_AUD_UNSQ			85		// 55 Generate PL tone
#define MSG_AUD_SQ			86		// 56 Disable Generate PL tone

	// Events associated with the Watchdog Timer Module

#define EV_WDOG_REFRESH		100	// 64 Refresh the watchdog timer



