/***************************************************************/
/*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.
*/
//		*** DATA STRUCTURE Definitions ***

#define Z_FIFO_BUF	20			// Size of fifo buffer.

struct TAG_FIFO
{
	byte inIdx;						// Input index
	byte outIdx;					// Output index
	byte count;						// Number of chars in FIFO
	byte buffer[Z_FIFO_BUF];	// The buffer itself.
} serialFIFO;



void SerialRS232Init(void)
{
//	byte ieStatus;
//	DI(ieStatus);		// Nested disable interrupts

	serialFIFO.inIdx = 0;	// Init FIFO buffer
	serialFIFO.outIdx = 0;
	serialFIFO.count = 0;

	UBRRH = HI_BYTE(BAUD19K2);
	UBRRL = LO_BYTE(BAUD19K2);

	// Set the 2x Bit in the Baud Rate Generator for 9600 or 19.2K Baud.
	// Clear it for 1200 Baud.

	UCSRA |= BV(U2X);

	 // Enable Rx and Tx.  Interrupts are not enabled.
//	UCSRB = (BV(RXEN) | BV(TXEN));

	 // Enable Rx and Tx, and enable Rx interrupts.

	UCSRB = (BV(RXEN) | BV(TXEN) | BV(RXCIE));

	// Set frame format: 8data, 2stop bit
	UCSRC = (BV(URSEL) | BV(USBS) | BV(UCSZ0) | BV(UCSZ1));

//	EI(ieStatus);		// Nested enable interrupts
}



// Put a character into the FIFO (called by ISR)

// If the buffer is already full, the character is lost.

void SerialInFIFO(char c)
{
//	byte ieStatus;
//	DI(ieStatus);		// Not needed if called by ISR

	if(count < Z_FIFO_BUF)
	{
		// Send an event if the buffer was empty when called.

		if(count == 0)
			SendEvent(SM_SIO, EV_DAV);	// Say data available.

		count++;
		buffer[inIdx++] = c;
		inIdx = (inIdx == Z_FIFO_BUF)? 0 : inIdx;	// Wrap
	}

//	EI(ieStatus);		// Not needed if called by ISR.

}

// Get a character from the FIFO

// If no character is available, '\0' is returned.  Use
// SerialFIFOEmpty to determine if a character is available.

byte SerialOutFIFO(void)
{
	byte c = 0x00;
	byte ieStatus;

	DI(ieStatus);		// Nested disable interrupts

	if(count > 0)
	{
		count--;
		c = buffer[outIdx++];
		outIdx = (outIdx == Z_FIFO_BUF)? 0 : outIdx;	// Wrap
	}

	EI(ieStatus);		// Nested enable interrupts

	return(c);
}

// Tell caller if there is data in the FIFO

// Returns TRUE if the FIFO is empty, FALSE otherwise.

bool SerialFIFOEmpty(void)
{
	return(count == 0);
}

