/***************************************************************
*																					*
*	cdebug.c: Run-Time Debugging Helps in C							*
*																					*
*	Originally developed for PSE-407 Repeater Controller			*
*																					*
*	Copyright 2004 by Pion and Simon Electronics.  All				*
*	rights reserved.															*
*																					*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.
****************************************************************/

//		*** INCLUDE FILES ***

#include <avr/pgmspace.h>
#include <avr/interrupt.h>

#include "avrstd.h"
#include "app.h"
#include "avrapex.h"
#include "bitio.h"
#include "serial.h"
#include "cdebug.h"


/***************************************************************/

//		*** STATIC FUNCTION PROTOTYPES ****

/***************************************************************/

//		*** VARIABLES ***
#ifdef CDEBUG

static byte markCount = 0;	// Number of passes before DB_Mark fires.

/***************************************************************/



//		*** API ***

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

	// Pause execution.  Execution is restarted by entering
	// any character.  The idChar is printed to the terminal.

void DB_Pause(byte idChar)
{
	Serial_TxFlashString((char *)PSTR("\r\nPause "));
	Serial_TxChar(idChar);
	Serial_CRLF();
	Serial_RxChar();	// Wait for user to type a char.
}

void DB_PrintMsg(char *pMsg)
{
	Serial_TxFlashString(pMsg);
}

void DB_PrintString(char *pStr)
{
	Serial_TxString(pStr);
	Serial_TxChar(' ');
}

void DB_PrintByte(byte num)
{
	Serial_TxHexChar(num);
	Serial_TxChar(' ');
}

void DB_PrintWord(word num)
{
	Serial_TxHexChar(HI_BYTE(num));
	Serial_TxHexChar(LO_BYTE(num));
	Serial_TxChar(' ');
}

void DB_PrintLong(unsigned long num)
{
	word numWord;

	numWord = HI_WORD(num);
	Serial_TxHexChar(HI_BYTE(numWord));
	Serial_TxHexChar(LO_BYTE(numWord));
	numWord = LO_WORD(num);
	Serial_TxHexChar(HI_BYTE(numWord));
	Serial_TxHexChar(LO_BYTE(numWord));
	Serial_TxChar(' ');
}

void DB_PrintEvent(MSG *pEvent)
{
	Serial_CRLF();
	Serial_TxChar('M');
	Serial_TxChar('-');
	Serial_TxHexChar(pEvent->dest);
	Serial_TxChar('-');
	Serial_TxHexChar(pEvent->id);
	Serial_TxChar(' ');
}

void DB_CRLF(void)
{
	Serial_CRLF();
}

void DB_Mark(byte count)
{
	if(++markCount == count)
	{
		cli();	// non-nested disable interrupts
		sbi(PORTB,2);	// Debug Pin
		FOREVER ;
	}
}


void DB_SetState(void (*pState)(MSG *pEvent), char stateChar)
{
	Serial_TxChar(stateChar);
	Ex_SetState(pState);
}


void DB_High(void)
{
	sbi(PORTB,4);
}
void DB_Low(void)
{
	cbi(PORTB,4);
}


void DB_Strobe(void)
{
	sbi(PORTB,4);
	cbi(PORTB,4);
}
#endif
