/***************************************************************
*																					*
*	exec.h: Event Processing Executive, Function Prototypes		*
*																					*
*	Originally developed for PSE-407 Repeater Controller			*
*																					*
*	Copyright 2004 by Pion and Simon Electronics.  All				*
*	rights reserved.															*
*																					*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.
****************************************************************/


#define FATAL				Ex_FatalError(__FILE__, __LINE__, 0)
#define FATAL_D(X)		Ex_FatalError(__FILE__, __LINE__, (X))

//		*** DATA STRUCTURE DEFINITIONS ***

typedef struct TAG_MSG_LINK
{
	struct TAG_MSG *pNext;	// Pointer to next message in list
	struct TAG_MSG *pPrev;	// Pointer to previous message in list

} MSG_LINK;

typedef struct TAG_MSG
{
	struct TAG_MSG *pNext;	// Next and previous messages in list.
	struct TAG_MSG *pPrev;

	byte	state;		// Current state of this message
#define MS_FREE		0	// Message is unused.
#define MS_SENT		1	// In queue, awaiting delivery
#define MS_DELIVERED	2	// Message is delivered to dest task.

	byte	allocType;	// Type of allocation of message
#define MT_POOL	0		// Message was allocated from the pool
#define MT_TIMER	1		// Message was allocated from a timer.

	byte	dest;			// Number of destination state machine
	byte	id;			// Code number identifying message
	word	wData;		// Data or pointer associated w/ message

} MSG;


typedef struct TAG_TIMER
{
	byte type;
#define TT_UNINITIALIZED	0	// Timer has not been initialized.
#define TT_POLL_TIMER		1	// Timer is a polling timer.
#define TT_EVENT_TIMER		2	// Timer is an event timer.

	byte state;
#define TS_STOPPED	0		// Timer state is "stopped"
#define TS_RUNNING	1		// Timer state is "running"
#define TS_TIMED_OUT	2		// Timer has timed out.

	word prescaler;		// Counts down prescaler
	word resetPrescaler;	// Reloads prescaler
	word timeCount;		// Counts down timer.
	word resetTime;		// Reloads timer

	MSG	event;			// Event to send upon timeout.

	void (*pServiceFunc)(void);	// Service address

} TIMER;


//		*** OPERATING SYSTEM FUNCTION PROTOTYPES ***

void Ex_InitTask(byte taskNum, void (*pInitAddr)(void));
void Ex_SetState(void (*pState)(MSG *pEvent));

void Ex_SendEvent(byte dest, byte id);
void Ex_SendEventExt(byte dest, byte id, word wData);
void Ex_SendMsg(byte dest, byte id);
void Ex_SendMsgExt(byte dest, byte id, word wData);

//bool Ex_DeleteEvent(byte id);
//bool Ex_DeleteMsg(byte id);

void Ex_StartPollTimer(
	byte timerNum, word duration, void (*pServiceFunc)(void));
void Ex_StartEventTimer(
	byte timerNum, word prescaler, word duration, byte id);

void Ex_StopTimer(byte timerNum);
bool Ex_TimerIsRunning(byte timerNum);
unsigned long Ex_GetSystemTime(void);

void Ex_FatalError(char *file, int line, byte data);


//		*** FUNCTIONS PROVIDED BY THE APPLICATION ***

void App_InitIO(void);
void App_InitTasks(void);
void App_FatalError(char *file, int line, byte data);


//		*** Timer Prescalers ***

#define TP_1MS			1			// Timer counts milliseconds
#define TP_10MS		10			// Timer counts 10's of mS.
#define TP_100MS		100		// Timer counts 100's of mS.
#define TP_SEC			1000		// Timer counts seconds.

