/***************************************************************
*																					*
*	morse.h: Waveform Generator Audio Ouput, API Definition		*
*																					*
*	Originally developed for PSE-407 Repeater Controller			*
*																					*
*	Copyright 2004 by Pion and Simon Electronics.  All				*
*	rights reserved.															*
*																					*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.
****************************************************************

	Morse Code API %% Needs Revision !!!!!

	The API consists of the following functions:

	MorseTaskReset: This routine initializes the Morse task
	from an unknown state.  It should be called by the
	power-up reset routine.

	MorseStart: This routine is called by external modules
	to initiate Morse Task execution.  Callers can monitor
	completion of the Morse Task by watching the GF1_MORSE_CP
	flag.  The GF1_MORSE_CP is cleared by MorseStart and is
	set by MorseTask after all morse code output is complete.

	MorseTask: Executed when the task flag is set.  This task
	causes output of various messages in morse code.  The
	messages include the Tx Timer Timeout message (TO), the
	CW identification message (CWID), The DTMF error message
	(ERR), the DTMF OK message (OK), etc.  The hang timer is
	also timed by the Morse task.  The Morse task outputs
	all messages indicated by the flags in the RMCF register
	before setting GF1_MORSE_CP.

	Morse Response Flags: The user can schedule various
	messages to be sent via morse code by setting the
	appropriate flags in the RMCF register.  When the user
	wishes the morse code to begin transmitting, the user
	calls MorseStart, and monitors the GF1_MORSE_CP flag
	to determine when the output is complete.

	ISR_Tim2Ocm: This function is called by an output compare
	interrupt, and is used to turn the output waveform on
	and off at a zero crossing.  This prevents the DC level
	of the output waveform from being upset.

	MorseTmr: This is a timer called by a 1ms timebase.  It
	times the periods for dots, dashes, and spaces between
	them.

	TailTmrISR: This timer times the duration of the
	transmitter hang time.  It is called by an ISR on a 10mS
	timebase.

	MdlyTmrISR: This timer times the duration of transmitter
	dead-air time at the start and end of morse code output.
	It is called by an ISR on a 10mS timebase.

***************************************************************/

//		*** GENERAL DEFINITIONS ***

#define MIN_MORSE_CODE_RATE	10		// Min = 10 wpm.
#define MAX_MORSE_CODE_RATE	20		// Max = 20 wpm.


//		*** DATA STRUCTURE DEFINITIONS ***

//		*** PUBLIC FUNCTION PROTOTYPES ***

void Morse_Init(void);
void Morse_DlyTmrISR(void);
void Morse_DitTmrISR(void);
char Morse_GetCharFromTable(byte index);
