/***************************************************************
*																					*
*	parse.h: API for Serial Command Parser								*
*																					*
*	Originally developed for PSE-407 Repeater Controller			*
*																					*
*	Copyright 2004 by Pion and Simon Electronics.  All				*
*	rights reserved.															*
*																					*
    This file is part of the PSE-508 project

    The PSE-508 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The PSE-508 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this file.  If not, see <http://www.gnu.org/licenses/>.
****************************************************************/


#define Z_DTMF_PASSWORD		4		// 3 character password + '\0'

	// CW and Voice ID Modes for K command:

#define MODE_ID_CW			0		// CW ID, No Announcements
#define MODE_ID_VOICE		1		// Voice ID, No Announcements
#define MODE_ID_TIMED_ANN	2		// CW ID, Timed Announcements
#define MODE_ID_MANUAL_ANN	3		// CW ID, Manual Announcements

	// CTCSS Encode Modes:

#define MODE_ECTCSS_OFF		0		// No PL Encode.
#define MODE_ECTCSS_RUS		1		// Encode on RUS only.
#define MODE_ECTCSS_PTT		2		// Encode on PTT.


//		*** DATA STRUCTURE DEFINITIONS ***


//		*** PUBLIC FUNCTION PROTOTYPES ***

void Parse_Init(void);
void Parse_InitLexLine(void);
void Parse_LexLine(char c);

void EEP_Init(void);

char *EEP_GetCWIDString(void);
void EEP_SetCWIDString(char *pString);

char *EEP_GetDTMFPassword(void);

byte EEP_GetPLDecodeNum(void);
byte EEP_GetPLEncodeNum(void);
//byte EEP_GetPLEncodeLevel(void);
byte EEP_CTCSSEncodeMode(void);

#ifdef PL_TWEEK
byte EEP_GetPLTweek(void);
#endif

byte EEP_GetMorseRate(void);
word EEP_GetMorseFreq(void);
byte EEP_GetMorseLevel(void);

word EEP_GetCourtesyBeepFreq(void);
byte EEP_GetCourtesyBeepLevel(void);
word EEP_GetCBDelay(void);

word EEP_GetHangTime(void);
word EEP_GetTxTimeout(void);
word EEP_GetIDTimeout(void);
word EEP_GetPLDecodeTimeout(void);

//byte EEP_GetChannelFlags(void);

bool EEP_HangTimeIsEnabled(void);
bool EEP_DTMFMuteIsEnabled(void);
bool EEP_TxIsEnabled(void);
bool EEP_DecodePL(void);
bool EEP_EncodePL(void);
bool EEP_CourtesyBeepEnabled(void);
bool EEP_RevBurstIsEnabled(void);

word EEP_GetVoiceIDDuration(void);

bool EEP_IDModeIsCW(void);
bool EEP_AnnouncementEnabled(void);
bool EEP_TimedAnnouncementMode(void);
bool EEP_ManualAnnouncement(void);
word EEP_GetAnnouncementPeriod(void);
//bool EEP_EncodeOnAnnouncements(void);

	// 'Set' Commands:

void EEP_SetPLDecodeState(bool state);
void EEP_SetPLEncodeState(bool state);
void EEP_SetTxEnableState(bool state);
void EEP_SetCourtesyBeepState(bool state);
void EEP_SetDTMFMuteState(bool state);
//void EEP_SetPLEncodeAnnouncements(bool state);
void EEP_SetReverseBurstState(bool state);

void EEP_SetVoiceIDDuration(word duration);
void EEP_SetIDMode(byte mode);
void EEP_SetCTCSSEncodeMode(byte mode);

#ifdef PL_TWEEK
void EEP_SetPLTweek(byte tweek);
#endif
